All built-in elements.
This module can be overridden in your own crate to add custom HTML elements.
See the documentation for define_elements! or GlobalAttributes for
more information.
Structs
- a
- A hyperlink (a hypertext anchor) labeled by its contents.
- abbr
- An abbreviation or acronym, optionally with its expansion.
- address
- The contact information for its nearest article or body element ancestor.
- annotation
mathml - annotation_
xml mathml - area
- Either a hyperlink with some text and a corresponding area on an image map, or a dead area on an image map.
- article
- A complete, or self-contained, composition in a document, page, application, or site and that is, in principle, independently distributable or reusable, e.g. in syndication.
- aside
- A section of a page that consists of content that is tangentially
related to the content around the
asideelement, and which could be considered separate from that content. - audio
- A sound or audio stream.
- b
- A span of text to which attention is being drawn for utilitarian purposes without conveying any extra importance and with no implication of an alternate voice or mood, such as key words in a document abstract, product names in a review, actionable words in interactive text-driven software, or an article lede.
- base
- Allows authors to specify the document base URL for the purposes of parsing URLs, and the name of the default navigable for the purposes of following hyperlinks.
- bdi
- A span of text that is to be isolated from its surroundings for the purposes of bidirectional text formatting.
- bdo
- Explicit text directionality formatting control for its children.
- blockquote
- A section that is quoted from another source.
- body
- The contents of the document.
- br
- A line break.
- button
- A button labeled by its contents.
- canvas
- A resolution-dependent bitmap canvas, which can be used for rendering graphs, game graphics, art, or other visual images on the fly. A canvas element.
- caption
- The title of the
tablethat is its parent, if it has a parent and that is atableelement. - cite
- The title of a work (e.g. a book, a paper, an essay, a poem, a score, a song, a script, a film, a TV show, a game, a sculpture, a painting, a theatre production, a play, an opera, a musical, an exhibition, a legal case report, a computer program, etc.).
- code
- A fragment of computer code.
- col
- One or more columns in the column group represented by a parent
colgroup. - colgroup
- A group of one or more columns in the
tablethat is its parent, if it has a parent and that is atableelement. - data
- Provide a machine-readable form of those contents in the
valueattribute. - datalist
- A set of option elements that represent predefined options for other controls.
- dd
- The description, definition, or value, part of a term-description group
in a description list (
dlelement). - del
- A removal from the document.
- details
- A disclosure widget from which the user can obtain additional information or controls.
- dfn
- The defining instance of a term.
- dialog
- A transitory part of an application, in the form of a small window (“dialog box”), which the user interacts with to perform a task or gather information.
- div
- No special meaning at all.
- dl
- An association list consisting of zero or more name-value groups (a description list).
- dt
- The term, or name, part of a term-description group in a description
list (
dlelement). - em
- Stress emphasis of its contents.
- embed
- An integration point for an external application or interactive content.
- fieldset
- A set of form controls (or other content) grouped together, optionally with a caption.
- figcaption
- A caption or legend for the rest of the contents of the
figcaptionelement’s parentfigureelement, if any. - figure
- Some flow content, optionally with a caption, that is self-contained (like a complete sentence) and is typically referenced as a single unit from the main flow of the document.
- footer
- A footer for its nearest ancestor sectioning content element, or for the body element if there is no such ancestor.
- form
- A hyperlink that can be manipulated through a collection of form-associated elements, some of which can represent editable values that can be submitted to a server for processing.
- h1
- Heading for its section.
- h2
- Heading for its section.
- h3
- Heading for its section.
- h4
- Heading for its section.
- h5
- Heading for its section.
- h6
- Heading for its section.
- head
- A collection of metadata for the document.
- header
- A group of introductory or navigational aids.
- hgroup
- A heading and related content.
- hr
- A paragraph-level thematic break, e.g., a scene change in a story, or a transition to another topic within a section of a reference book; alternatively, it represents a separator between a set of options of a select element.
- html
- The root of an HTML document.
- i
- A span of text in an alternate voice or mood, or otherwise offset from the normal prose in a manner indicating a different quality of text, such as a taxonomic designation, a technical term, an idiomatic phrase from another language, transliteration, a thought, or a ship name in Western texts.
- iframe
- Contains a content navigable.
- img
- An image.
- input
- A typed data field, usually with a form control to allow the user to edit the data.
- ins
- An addition to the document.
- kbd
- User input (typically keyboard input, although it may also be used to represent other input, such as voice commands).
- label
- A caption in a user interface.
- legend
- A caption for the rest of the contents of the
legendelement’s parentfieldsetelement, if any. - li
- A list item.
- link
- Allows authors to link their document to other resources.
- main
- The dominant contents of the document.
- map
- Defines an image map.
- mark
- A run of text in one document marked or highlighted for reference purposes, due to its relevance in another context.
- math
mathml - menclose
mathml - menu
- A toolbar consisting of its contents, in the form of an unordered list of items (represented by li elements), each of which represents a command that the user can perform or activate.
- merror
mathml - meta
- Various kinds of metadata that cannot be expressed using the
title,base,link,style, andscriptelements. - meter
- A scalar measurement within a known range, or a fractional value; for example disk usage, the relevance of a query result, or the fraction of a voting population to have selected a particular candidate.
- mfrac
mathml - mi
mathml - mmultiscripts
mathml - mn
mathml - mo
mathml - mover
mathml - mpadded
mathml - mphantom
mathml - mprescripts
mathml - mroot
mathml - mrow
mathml - ms
mathml - mspace
mathml - msqrt
mathml - mstyle
mathml - msub
mathml - msubsup
mathml - msup
mathml - mtable
mathml - mtd
mathml - mtext
mathml - mtr
mathml - munder
mathml - munderover
mathml - nav
- A section of a page that links to other pages or to parts within the page: a section with navigation links.
- noscript
- Does nothing if scripting is enabled, shows the fallback content if scripting is disabled.
- object
- An external resource, which, depending on the type of the resource, will either be treated as an image or as a child navigable.
- ol
- A list of items, where the items have been intentionally ordered, such that changing the order would change the meaning of the document.
- optgroup
- A group of
optionelements with a common label. - option
- An option in a
selectelement or as part of a list of suggestions in adatalistelement. - output
- The result of a calculation performed by the application, or the result of a user action.
- p
- A paragraph.
- picture
- A container which provides multiple sources to its contained
imgelement to allow authors to declaratively control or give hints to the user agent about which image resource to use, based on the screen pixel density, viewport size, image format, and other factors. - pre
- A block of preformatted text, in which structure is represented by typographic conventions rather than by elements.
- progress
- The completion progress of a task.
- q
- Some phrasing content quoted from another source.
- rp
- Parentheses or other content around a ruby text component of a ruby annotation, to be shown by user agents that don’t support ruby annotations.
- rt
- The ruby text component of a ruby annotation.
- ruby
- Allows one or more spans of phrasing content to be marked with ruby annotations.
- s
- Contents that are no longer accurate or no longer relevant.
- samp
- Sample or quoted output from another program or computing system.
- script
- Allows authors to include dynamic script and data blocks in their documents.
- search
- A part of a document or application that contains a set of form controls or other content related to performing a search or filtering operation.
- section
- A generic section of a document or application.
- select
- A control for selecting amongst a set of options.
- semantics
mathml - slot
- A slot in a shadow tree that can be filled with an arbitrary node.
- small
- Side comments such as small print.
- source
- Allows authors to specify multiple alternative source sets for
imgelements or multiple alternative media resources for media elements. - span
- No special meaning.
- strong
- Strong importance, seriousness, or urgency for its contents.
- style
- Allows authors to embed CSS style sheets in their documents.
- sub
- A subscript.
- summary
- A summary, caption, or legend for the rest of the contents of the summary element’s parent details element, if any.
- sup
- A superscript.
- table
- Data with more than one dimension, in the form of a table.
- tbody
- A block of rows that consist of a body of data for the parent
tableelement, if thetbodyelement has a parent and it is atable. - td
- A data cell in a table.
- template
- Used to declare fragments of HTML that can be cloned and inserted in the document by script.
- textarea
- A multiline plain text edit control for the element’s raw value.
- tfoot
- The block of rows that consist of the column summaries (footers) for the
parent
tableelement, if thetfootelement has a parent and it is atable. - th
- A header cell in a table.
- thead
- The block of rows that consist of the column labels (headers) and any
ancillary non-header cells for the parent
tableelement, if thetheadelement has a parent and it is atable. - time
- Provide a machine-readable form of those contents in the
datetimeattribute. - title
- The document’s title or name.
- tr
- A row of cells in a table.
- track
- Allows authors to specify explicit external timed text tracks for media elements.
- u
- A span of text with an unarticulated, though explicitly rendered, non-textual annotation, such as labeling the text as being a proper name in Chinese text (a Chinese proper name mark), or labeling the text as being misspelt.
- ul
- A list of items, where the order of the items is not important — that is, where changing the order would not materially change the meaning of the document.
- var
- A variable.
- video
- Used for playing videos or movies, and audio files with captions.
- wbr
- A line break opportunity.